# -*- coding: utf-8 -*-
from setuphelpers import *


appx_package_name = "Microsoft.ScreenSketch"
appx_dir = makepath(programfiles, "WindowsAppsInstallers")
allow_remove = False


def install():
    # Declare local variables
    bins_dir = control.package.split("-", 1)[1]
    appx_bins_dir = makepath(appx_dir, bins_dir)

    # Remove from old path
    for appx_file in glob.glob(makepath(appx_dir, "%s_*" % appx_package_name)):
        remove_file(appx_file)

    # Placing bins for session-setup installs
    if isdir(appx_bins_dir):
        remove_tree(appx_bins_dir)
    mkdirs(appx_bins_dir)
    print(f"Creating: {appx_bins_dir}")
    for f in glob.glob(bins_dir + "/*"):
        filecopyto(f, appx_bins_dir)
    for f in glob.glob(appx_bins_dir + "/*"):
        if control.architecture == "all":
            fname = f.split(os.sep)[-1]
            if "x86" in glob.glob(makepath(appx_bins_dir, "%s_*" % appx_package_name))[0].split(os.sep)[-1]:
                if not "x86" in fname and not "neutral" in fname:
                    remove_file(f)
            else:
                if not get_host_architecture() in fname and not "neutral" in fname:
                    remove_file(f)
        else:
            if not control.architecture in fname and not "neutral" in fname:
                remove_file(f)


def session_setup():
    # Declare local variables
    bins_dir = control.package.split("-", 1)[1]
    appx_bins_dir = makepath(appx_dir, bins_dir)
    bin_path = glob.glob(makepath(appx_bins_dir, f"{appx_package_name}_*"))[0]
    dependencies_pathes = ",".join([f'"{a}"' for a in glob.glob(makepath(appx_bins_dir, "*")) if not appx_package_name in a])

    # Installing the UWP application in the user environment
    appx_version = get_powershell_str("Get-AppxPackage -Name %s" % appx_package_name, "Version")
    if not appx_version or Version(appx_version) < Version(control.get_software_version()) or force:
        print("Installing: %s" % bin_path.split("\\")[-1])
        killalltasks(control.get_impacted_process_list())
        add_appx_cmd = f'Add-AppxPackage -Path "{bin_path}"'
        if dependencies_pathes:
            add_appx_cmd += f" -DependencyPath {dependencies_pathes}"
        run_powershell(add_appx_cmd)
    else:
        print("%s is installed in correct version (%s)" % (appx_package_name, appx_version))


def uninstall():
    # Declare local variables
    bins_dir = control.package.split("-", 1)[1]
    appx_bins_dir = makepath(appx_dir, bins_dir)

    if allow_remove:
        remove_appx(appx_package_name)
    if isdir(appx_bins_dir):
        print("Remove: %s" % (appx_bins_dir))
        remove_tree(appx_bins_dir)
    if dir_is_empty(appx_dir):
        print("Remove: %s since it is empty" % (appx_dir))
        remove_tree(appx_dir)


def get_host_architecture():
    if isARM64():
        return "arm64"
    elif isARM():
        return "arm"
    elif is64():
        return "x64"
    elif is32():
        return "x86"
